#!/usr/bin/python3
# -*- coding: utf-8 -*-
#
#
# Copyright (C) 2010 Lorenzo Carbonell
# lorenzo.carbonell.cerezo@gmail.com
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
#
import codecs
import os
import json

CONFIG_DIR = os.path.join(os.path.expanduser('~'),'.config')
CONFIG_APP_DIR = os.path.join(CONFIG_DIR, 'pushbullet')
CONFIG_FILE = os.path.join(CONFIG_APP_DIR, 'pushbullet.conf')

DEFAULT_PARAMS = {
			'oauth_access_token':None,
			'access_token':None,
			}
			
class Configuration(object):
	def __init__(self):
		self.params = DEFAULT_PARAMS
		self.read()
	
	def get(self,key):
		try:
			return self.params[key]
		except KeyError as e:
			print(e)
			self.params[key] = DEFAULT_PARAMS[key]
			return self.params[key]
		
	def set(self,key,value):
		self.params[key] = value

	def reset(self):
		if os.path.exists(CONFIG_FILE):
			os.remove(CONFIG_FILE)		
		self.params = DEFAULT_PARAMS
		self.save()

	def set_defaults(self):
		self.params = DEFAULT_PARAMS
		self.save()
	
	def read(self):		
		try:
			f=codecs.open(CONFIG_FILE,'r','utf-8')
		except IOError as e:
			print(e)
			self.save()
			f=codecs.open(CONFIG_FILE,'r','utf-8')
		try:
			self.params = json.loads(f.read())
		except ValueError as e:
			print(e)
			self.save()
		f.close()

	def save(self):
		if not os.path.exists(CONFIG_APP_DIR):
			os.makedirs(CONFIG_APP_DIR)
		f=codecs.open(CONFIG_FILE,'w','utf-8')
		f.write(json.dumps(self.params))
		f.close()
