#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# pushbulet_dialogs.py
#
# This file is part of PushBullet-Indicator
#
# Copyright (C) 2014
# Lorenzo Carbonell Cerezo <lorenzo.carbonell.cerezo@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import gi
gi.require_version('Gtk', '3.0')
from gi.repository import Gtk
from gi.repository import Gdk
from gi.repository import GdkPixbuf
import os
from os.path import splitext, basename
import commons_comun
from commons_comun import _
from commons_configurator import Configuration
from commons_comun import internet_on
try:
	from urllib.request import urlopen
	from urllib.request import Request
	from urllib.parse import urlparse
	from urllib.request import url2pathname
except ImportError:
	from urllib import url2pathname
	from urllib import urlopen
	from urllib2 import Request
	from urlparse import urlparse
NOTE_PAGE = 0
LINK_PAGE = 1
FILE_PAGE = 2
IMAGE_PAGE = 3

class DropArea(Gtk.EventBox):
	def __init__(self,on_clicked_response=False, message=_('Drop one file on me!')):
		Gtk.EventBox.__init__(self)
		self.label = Gtk.Label(message)
		dnd_list = Gtk.TargetEntry.new('text/uri-list', 0, 0)
		self.label.drag_dest_set(Gtk.DestDefaults.MOTION | Gtk.DestDefaults.HIGHLIGHT | Gtk.DestDefaults.DROP,[dnd_list],Gdk.DragAction.MOVE )
		self.label.drag_dest_add_uri_targets()		
		self.label.connect('drag-data-received', self.on_drag_data_received)
		self.add(self.label)
		self.connect('button_press_event',self.on_clicked)
		self.filename = None
		self.fileurl = None
		self.on_clicked_response = on_clicked_response
	def on_clicked(self,widget,data):
		if self.filename and self.fileurl and self.on_clicked_response:
			dialog = Gtk.FileChooserDialog(_('Please choose a directory to download the file'), None,
			Gtk.FileChooserAction.SELECT_FOLDER,(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,	Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
			response = dialog.run()
			if response == Gtk.ResponseType.OK:
				dialog.hide()
				directory = dialog.get_filename()
				dialog.destroy()
				while Gtk.events_pending():
					Gtk.main_iteration()	
				print(self.fileurl)
				filename = os.path.join(directory,basename(urlparse(self.fileurl).path))
				headers = {'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11',
					'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
					'Accept-Charset': 'ISO-8859-1,utf-8;q=0.7,*;q=0.3',
					'Accept-Encoding': 'none',
					'Accept-Language': 'en-US,en;q=0.8',
					'Connection': 'keep-alive'}
				arequest = Request(self.fileurl, headers=headers)
				page = urlopen(arequest)
				with open(filename, 'bw') as f:
					f.write(page.read())				
			else:
				dialog.destroy()
             
	def on_drag_data_received(self, widget, drag_context, x,y, selection_data,info, time):		
		if info == 0:
			response = []
			filenames = selection_data.get_uris()
			self.fileurl = url2pathname(filenames[0])[7:]
			self.filename = os.path.basename(self.fileurl)
			self.label.set_text(self.filename)
				
	def set_filename(self,filename):
		self.filename = filename
		self.label.set_text(filename+'\n\n'+_('(Click on me to download file)'))

	def get_filename(self):
		return self.filename

	def set_fileurl(self,fileurl):
		self.fileurl = fileurl
	
	def get_fileurl(self):
		return self.fileurl

class SendToDialog(Gtk.Dialog):
	def __init__(self,devices=None,contacts=None):
		#
		Gtk.Dialog.__init__(self, _('PushBullet action'),None,Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,(Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT,Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT))
		self.set_position(Gtk.WindowPosition.CENTER_ALWAYS)
		self.connect('close', self.close_application)
		self.set_icon_from_file(commons_comun.ICON)
		#
		vbox0 = Gtk.VBox(spacing = 5)
		vbox0.set_border_width(5)
		#vbox0.set_size_request(400, 80)
		self.get_content_area().add(vbox0)
		'''
		devices = []
		devices.append({'label':'1','device_iden':'11'})
		devices.append({'label':'2','device_iden':'12'})
		devices.append({'label':'3','device_iden':'13'})
		contacts = []
		contacts.append({'name':'4','contact_iden':'41'})
		contacts.append({'name':'5','contact_iden':'52'})
		contacts.append({'name':'6','contact_iden':'63'})
		'''
		#***************************************************************
		table_to = Gtk.Table(2, 2, False)
		vbox0.pack_start(table_to,False,False,0)
		label_to = Gtk.Label(_('Send bullet to')+':')
		label_to.set_alignment(0, 0.5)
		table_to.attach(label_to,0,1,0,1, xpadding=5, ypadding=5)			
		name_store = Gtk.ListStore(str,str,GdkPixbuf.Pixbuf,str)
		toall = GdkPixbuf.Pixbuf.new_from_file_at_size(os.path.join(commons_comun.ICONDIR,"infinity.svg"), 32, 32)
		tomobile = GdkPixbuf.Pixbuf.new_from_file_at_size(os.path.join(commons_comun.ICONDIR,"mobile.svg"), 32, 32)
		touser = GdkPixbuf.Pixbuf.new_from_file_at_size(os.path.join(commons_comun.ICONDIR,"user.svg"), 32, 32)
		name_store.append([_('All'),'',toall,'all'])
		for adevice in devices:			
			name_store.append([adevice['label'],adevice['device_iden'],tomobile,'device'])
		for acontact in contacts:			
			name_store.append([acontact['name'],acontact['contact_iden'],touser,'contact'])
		self.bulletTo = Gtk.ComboBox.new_with_model(name_store)		
		renderertext = Gtk.CellRendererText()
		renderertext.props.mode = Gtk.CellRendererMode.ACTIVATABLE
		self.bulletTo.pack_start(renderertext, False)
		self.bulletTo.add_attribute(renderertext, "text", 0)				
		renderer = Gtk.CellRendererPixbuf()
		self.bulletTo.pack_start(renderer, False)
		self.bulletTo.add_attribute(renderer, "pixbuf", 2)					
		table_to.attach(self.bulletTo,1,2,0,1, xpadding=5, ypadding=5)
		self.bulletTo.set_active(0)
		self.show_all()

	def get_selected_in_combo(self):
		tree_iter = self.bulletTo.get_active_iter()
		if tree_iter != None:
			model = self.bulletTo.get_model()
			label, iden, pb, ttype = model[tree_iter]
			return {'label':label,'iden':iden,'type':ttype}	
		return None
		
	def get_response(self):
		return self.get_selected_in_combo()
		
	def close_application(self, widget):
		self.hide()
				
class ActionDialog(Gtk.Dialog):

	def __init__(self,push=None,devices=None,contacts=None):
		#
		Gtk.Dialog.__init__(self, _('PushBullet action'),None,Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,(Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT,Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT))
		self.set_position(Gtk.WindowPosition.CENTER_ALWAYS)
		self.connect('close', self.close_application)
		self.set_icon_from_file(commons_comun.ICON)
		#
		vbox0 = Gtk.VBox(spacing = 5)
		vbox0.set_border_width(5)
		vbox0.set_size_request(400, 400)
		self.get_content_area().add(vbox0)
		'''
		devices = []
		devices.append({'label':'1','device_iden':'11'})
		devices.append({'label':'2','device_iden':'12'})
		devices.append({'label':'3','device_iden':'13'})
		contacts = []
		contacts.append({'name':'4','contact_iden':'41'})
		contacts.append({'name':'5','contact_iden':'52'})
		contacts.append({'name':'6','contact_iden':'63'})
		'''
		self.bulletTo = None
		#***************************************************************
		if devices is not None and contacts is not None:
			table_to = Gtk.Table(2, 2, False)
			vbox0.pack_start(table_to,True,True,0)
			label_to = Gtk.Label(_('To')+':')
			label_to.set_alignment(0, 0.5)
			table_to.attach(label_to,0,1,0,1, xpadding=5, ypadding=5)			
			name_store = Gtk.ListStore(str,str,GdkPixbuf.Pixbuf,str)
			toall = GdkPixbuf.Pixbuf.new_from_file_at_size(os.path.join(commons_comun.ICONDIR,"infinity.svg"), 32, 32)
			tomobile = GdkPixbuf.Pixbuf.new_from_file_at_size(os.path.join(commons_comun.ICONDIR,"mobile.svg"), 32, 32)
			touser = GdkPixbuf.Pixbuf.new_from_file_at_size(os.path.join(commons_comun.ICONDIR,"user.svg"), 32, 32)
			name_store.append([_('All'),'',toall,'all'])
			for adevice in devices:			
				name_store.append([adevice['label'],adevice['device_iden'],tomobile,'device'])
			for acontact in contacts:			
				name_store.append([acontact['name'],acontact['contact_iden'],touser,'contact'])
			#self.bulletTo = Gtk.ComboBox.new_with_model_and_entry(name_store)		
			self.bulletTo = Gtk.ComboBox.new_with_model(name_store)		
			renderertext = Gtk.CellRendererText()
			renderertext.props.mode = Gtk.CellRendererMode.ACTIVATABLE
			self.bulletTo.pack_start(renderertext, False)
			self.bulletTo.add_attribute(renderertext, "text", 0)				
			renderer = Gtk.CellRendererPixbuf()
			self.bulletTo.pack_start(renderer, False)
			self.bulletTo.add_attribute(renderer, "pixbuf", 2)					
			table_to.attach(self.bulletTo,1,2,0,1, xpadding=5, ypadding=5)
			self.bulletTo.set_active(0)
		
		self.notebook = Gtk.Notebook()
		self.notebook.set_tab_pos(Gtk.PositionType.BOTTOM)
		vbox0.pack_start(self.notebook,True,True,0)		
		self.action = {}
		#
		self.action['note'] = {}
		frame_note = Gtk.Frame()
		frame_note.set_border_width(10)
		vbox_note = Gtk.VBox()
		frame_note.add(vbox_note)
		table_note = Gtk.Table(2, 2, False)
		vbox_note.pack_start(table_note,False,False,0)
		label_note_1 = Gtk.Label(_('Title')+':')
		label_note_1.set_alignment(0, 0.5)
		table_note.attach(label_note_1,0,1,0,1, xpadding=5, ypadding=5)
		self.action['note']['title'] = Gtk.Entry()
		table_note.attach(self.action['note']['title'],1,2,0,1, xpadding=5, ypadding=5)
		label_note_2 = Gtk.Label(_('Message')+':')
		label_note_2.set_alignment(0, 0.5)
		table_note.attach(label_note_2,0,1,1,2, xpadding=5, ypadding=5)		
		scrolledwindow_note = Gtk.ScrolledWindow()
		scrolledwindow_note.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
		scrolledwindow_note.set_shadow_type(Gtk.ShadowType.ETCHED_OUT)
		table_note.attach(scrolledwindow_note,1,2,1,2, xpadding=5, ypadding=5)
		self.action['note']['body'] = Gtk.TextView()
		self.action['note']['body'].set_wrap_mode(Gtk.WrapMode.WORD)
		scrolledwindow_note.add(self.action['note']['body'])
		scrolledwindow_note.set_size_request(200, 200)
		image_note = Gtk.Image()
		image_note.set_from_file(commons_comun.NOTE_ICON)
		image_note_container = Gtk.Button()
		image_note_container.set_name('note')
		image_note_container.set_tooltip_text(_('Note'))
		image_note_container.set_size_request(24,24)
		image_note_container.set_image(image_note)
		image_note_container.connect('clicked',self.on_container_clicked,'note')
		self.notebook.append_page(frame_note,image_note_container)	
		#
		self.action['link'] = {}
		frame_link = Gtk.Frame()
		frame_link.set_border_width(10)
		vbox_link = Gtk.VBox()
		frame_link.add(vbox_link)
		table_link = Gtk.Table(2, 2, False)
		vbox_link.pack_start(table_link,False,False,0)
		label_link_1 = Gtk.Label(_('Title')+':')
		label_link_1.set_alignment(0, 0.5)
		table_link.attach(label_link_1,0,1,0,1, xpadding=5, ypadding=5)
		self.action['link']['title'] = Gtk.Entry()
		table_link.attach(self.action['link']['title'],1,2,0,1, xpadding=5, ypadding=5)
		label_link_2 = Gtk.Label(_('Link')+':')
		label_link_2.set_alignment(0, 0.5)
		table_link.attach(label_link_2,0,1,1,2, xpadding=5, ypadding=5)
		self.action['link']['link'] = Gtk.Entry()
		table_link.attach(self.action['link']['link'],1,2,1,2, xpadding=5, ypadding=5)
		
		label_link_3 = Gtk.Label(_('Message')+':')
		label_link_3.set_alignment(0, 0.5)
		table_link.attach(label_link_3,0,1,2,3, xpadding=5, ypadding=5)		
		scrolledwindow_link = Gtk.ScrolledWindow()
		scrolledwindow_link.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
		scrolledwindow_link.set_shadow_type(Gtk.ShadowType.ETCHED_OUT)
		table_link.attach(scrolledwindow_link,1,2,2,3, xpadding=5, ypadding=5)
		self.action['link']['body'] = Gtk.TextView()
		self.action['link']['body'].set_wrap_mode(Gtk.WrapMode.WORD)
		scrolledwindow_link.add(self.action['link']['body'])
		scrolledwindow_link.set_size_request(200, 200)
		image_link = Gtk.Image()
		image_link.set_from_file(commons_comun.LINK_ICON)
		image_link_container = Gtk.Button()
		image_link_container.set_name('link')
		image_link_container.set_tooltip_text(_('Link'))
		image_link_container.set_size_request(24,24)
		image_link_container.set_image(image_link)
		image_link_container.connect('clicked',self.on_container_clicked,'link')
		self.notebook.append_page(frame_link,image_link_container)
		#
		self.action['file'] = {}
		frame_file = Gtk.Frame()
		frame_file.set_border_width(10)
		vbox_file = Gtk.VBox()
		frame_file.add(vbox_file)
		self.action['file']['file'] = DropArea(push is not None,_('Drop one file on me!'))
		vbox_file.pack_start(self.action['file']['file'],True,True,0)
		table_file = Gtk.Table(2, 2, False)
		vbox_file.pack_start(table_file,True,True,0)
		label_file = Gtk.Label(_('Message')+':')
		label_file.set_alignment(0, 0.5)
		table_file.attach(label_file,0,1,0,1, xpadding=5, ypadding=5)		
		scrolledwindow_file = Gtk.ScrolledWindow()
		scrolledwindow_file.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
		scrolledwindow_file.set_shadow_type(Gtk.ShadowType.ETCHED_OUT)
		table_file.attach(scrolledwindow_file,1,2,0,1, xpadding=5, ypadding=5)
		self.action['file']['body'] = Gtk.TextView()
		self.action['file']['body'].set_wrap_mode(Gtk.WrapMode.WORD)
		scrolledwindow_file.add(self.action['file']['body'])
		scrolledwindow_file.set_size_request(200, 100)		
		image_file = Gtk.Image()
		image_file.set_from_file(commons_comun.FILE_ICON)
		image_file_container = Gtk.Button()
		image_file_container.set_name('file')
		image_file_container.set_tooltip_text(_('File'))
		image_file_container.set_size_request(24,24)
		image_file_container.set_image(image_file)
		image_file_container.connect('clicked',self.on_container_clicked,'file')
		self.notebook.append_page(frame_file,image_file_container)
		#
		self.action['image'] = {}
		frame_image = Gtk.Frame()
		frame_image.set_border_width(10)
		vbox_image = Gtk.VBox()
		frame_image.add(vbox_image)
		self.action['image']['file'] = DropArea(push is not None,_('Drop one image on me!'))
		vbox_image.pack_start(self.action['image']['file'],True,True,0)
		
		table_image = Gtk.Table(2, 2, False)
		vbox_image.pack_start(table_image,True,True,0)
		label_image = Gtk.Label(_('Message')+':')
		label_image.set_alignment(0, 0.5)
		table_image.attach(label_image,0,1,0,1, xpadding=5, ypadding=5)		
		scrolledwindow_image = Gtk.ScrolledWindow()
		scrolledwindow_image.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
		scrolledwindow_image.set_shadow_type(Gtk.ShadowType.ETCHED_OUT)
		table_image.attach(scrolledwindow_image,1,2,0,1, xpadding=5, ypadding=5)
		self.action['image']['body'] = Gtk.TextView()
		self.action['image']['body'].set_wrap_mode(Gtk.WrapMode.WORD)
		scrolledwindow_image.add(self.action['image']['body'])
		scrolledwindow_image.set_size_request(200, 100)				
		
		image_image = Gtk.Image()
		image_image.set_from_file(commons_comun.IMAGE_ICON)
		image_image_container = Gtk.Button()
		image_image_container.set_name('image')
		image_image_container.set_tooltip_text(_('File'))
		image_image_container.set_size_request(24,24)
		image_image_container.set_image(image_image)
		image_image_container.connect('clicked',self.on_container_clicked,'image')
		self.notebook.append_page(frame_image,image_image_container)
		#
		style_provider = Gtk.CssProvider()
		css = """		
			#address{
				border-image: none;
				background-image: none;
				border-radius: 0px;
				background-color: @bg_color;
			}
			#address:hover{
				transition: 1000ms linear;
				border-image: none;
				background-image: none;
				border-radius: 0px;
				background-color: rgba(241, 196, 15, 255);
			}
			#link{
				border-image: none;
				background-image: none;
				border-radius: 0px;
				background-color: @bg_color;
			}
			#link:hover{
				transition: 1000ms linear;
				border-image: none;
				background-image: none;
				border-radius: 0px;
				background-color: rgba(52, 152, 219, 255);
			}
			#list{
				border-image: none;
				background-image: none;
				border-radius: 0px;
				background-color: @bg_color;
			}
			#list:hover{
				transition: 1000ms linear;
				border-image: none;
				background-image: none;
				border-radius: 0px;
				background-color: rgba(155, 89, 182, 255);
			}
			#file{
				border-image: none;
				background-image: none;
				border-radius: 0px;
				background-color: @bg_color;
			}
			#file:hover{
				transition: 1000ms linear;
				border-image: none;
				background-image: none;
				border-radius: 0px;
				background-color: rgba(231, 76, 60, 255);
			}
			#image{
				border-image: none;
				background-image: none;
				border-radius: 0px;
				background-color: @bg_color;
			}
			#image:hover{
				transition: 1000ms linear;
				border-image: none;
				background-image: none;
				border-radius: 0px;
				background-color: rgba(76, 231, 60, 255);
			}
			#note{
				border-image: none;
				background-image: none;
				border-radius: 0px;
				background-color: @bg_color;
			}
			#note:hover{
				transition: 1000ms linear;
				border-image: none;
				background-image: none;
				border-radius: 0px;
				background-color: rgba(230, 126, 34, 255);
			}
		"""
		style_provider.load_from_data(css.encode('UTF-8'))
		Gtk.StyleContext.add_provider_for_screen(
			Gdk.Screen.get_default(), 
			style_provider,     
			Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
		)
		self.show_all()
		if push is not None and 'type' in push.keys():
			if push['type'] == 'note':
				self.notebook.set_current_page(NOTE_PAGE)
				if 'title' in push:
					self.action['note']['title'].set_text(push['title'])
				if 'body' in push:
					self.action['note']['body'].get_buffer().set_text(push['body'])				
				self.notebook.remove_page(IMAGE_PAGE)
				self.notebook.remove_page(FILE_PAGE)
				self.notebook.remove_page(LINK_PAGE)
			elif push['type'] == 'link':
				self.notebook.set_current_page(LINK_PAGE)
				if 'title' in push:
					self.action['link']['title'].set_text(push['title'])
				if 'url' in push:
					self.action['link']['link'].set_text(push['url'])
				if 'body' in push:
					self.action['link']['body'].get_buffer().set_text(push['body'])				
				self.notebook.remove_page(LIST_PAGE)
				self.notebook.remove_page(FILE_PAGE)
				self.notebook.remove_page(NOTE_PAGE)
			elif push['type'] == 'file':
				self.notebook.set_current_page(FILE_PAGE)
				if 'file_name' in push:
					self.action['file']['file'].set_filename(push['file_name'])
				if 'file_url' in push:
					self.action['file']['file'].set_fileurl(push['file_url'])
				if 'body' in push:
					self.action['file']['body'].get_buffer().set_text(push['body'])				
				self.notebook.remove_page(IMAGE_PAGE)
				self.notebook.remove_page(LINK_PAGE)
				self.notebook.remove_page(NOTE_PAGE)
			elif push['type'] == 'image':
				self.notebook.set_current_page(IMAGE_PAGE)
				if 'file_name' in push:
					self.action['file']['file'].set_filename(push['file_name'])
				if 'file_url' in push:
					self.action['file']['file'].set_fileurl(push['file_url'])
				if 'body' in push:
					self.action['image']['body'].get_buffer().set_text(push['body'])				
				self.notebook.remove_page(FILE_PAGE)
				self.notebook.remove_page(LINK_PAGE)
				self.notebook.remove_page(NOTE_PAGE)
	#	
	def get_selected_in_combo(self):
		tree_iter = self.bulletTo.get_active_iter()
		if tree_iter != None:
			model = self.bulletTo.get_model()
			label, iden, pb, ttype = model[tree_iter]
			return {'label':label,'iden':iden,'type':ttype}
		
	def on_container_clicked(self,widget,container_id):
		if container_id == 'note':
			self.notebook.set_current_page(NOTE_PAGE)
		elif container_id == 'link':
			self.notebook.set_current_page(LINK_PAGE)
		elif container_id == 'file':
			self.notebook.set_current_page(FILE_PAGE)
		elif container_id == 'image':
			self.notebook.set_current_page(IMAGE_PAGE)
	def close_application(self, widget):
		self.hide()
	def get_response(self):
		page = self.notebook.get_current_page()
		response = {}
		if self.bulletTo is not None:
			ans = self.get_selected_in_combo()
			response['to'] = ans
		if page == FILE_PAGE:
			response['kind'] = 'file'
			response['file'] = self.action['file']['file'].get_fileurl()
			tbuffer =self.action['file']['body'].get_buffer()
			inicio = tbuffer.get_start_iter()
			fin = tbuffer.get_end_iter()
			response['body'] = tbuffer.get_text(inicio,fin,True)						
		elif page == IMAGE_PAGE:
			response['kind'] = 'image'
			response['file'] = self.action['image']['file'].get_fileurl()
			tbuffer =self.action['image']['body'].get_buffer()
			inicio = tbuffer.get_start_iter()
			fin = tbuffer.get_end_iter()
			response['body'] = tbuffer.get_text(inicio,fin,True)							
		elif page == LINK_PAGE:
			response['kind'] = 'link'
			response['title'] = self.action['link']['title'].get_text()
			link = self.action['link']['link'].get_text()
			if not link.startswith('http://') and not link.startswith('https://'):
				link = 'http://' + link
			response['link'] = link				
			tbuffer =self.action['link']['body'].get_buffer()
			inicio = tbuffer.get_start_iter()
			fin = tbuffer.get_end_iter()
			response['body'] = tbuffer.get_text(inicio,fin,True)				
		elif page == NOTE_PAGE:
			response['kind'] = 'note'
			response['title'] = self.action['note']['title'].get_text()
			tbuffer =self.action['note']['body'].get_buffer()
			inicio = tbuffer.get_start_iter()
			fin = tbuffer.get_end_iter()
			response['body'] = tbuffer.get_text(inicio,fin,True)
		else:
			response = None
		return response			

if __name__ == "__main__":
	from logindialog import LoginDialog
	'''
	from pushbulletapi import PushBullet
	configuration = Configuration()
	pb = PushBullet()
	print(pb.isLogin())
	while(pb.isLogin() == False and internet_on()):
		ld = LoginDialog()
		ld.run()
		oauth_access_token = ld.code
		configuration.set('oauth_access_token',oauth_access_token)
		configuration.save()
		pb = PushBullet()
	idevices = pb.getDevices()
	icontacts = pb.getContacts()
	tdevices = []
	tcontacts = []
	for device in idevices:
		if 'nickname' in idevices[device].keys() and len(idevices[device]['nickname'])>0:
			label = idevices[device]['nickname']
			tdevices.append({'device_iden':device,'label':label})
		elif 'model' in idevices[device].keys() and len(idevices[device]['model'])>0:
			label = idevices[device]['model']
			tdevices.append({'device_iden':device,'label':label})			
	sdevices = sorted(tdevices, key=lambda k: k['label']) 
	for contact in icontacts:
		if icontacts[contact]['active'] and 'name' in icontacts[contact].keys() and 'email' in icontacts[contact].keys():
			tcontacts.append({'contact_iden':contact,'name':icontacts[contact]['name'],'email':icontacts[contact]['email']})
	scontacts = sorted(tcontacts, key=lambda k: k['name']) 
	sdevices = sorted(tdevices, key=lambda k: k['label']) 				
	#cm = ActionDialog(None,sdevices,scontacts)
	'''
	cm = SendSMSDialog()
	if 	cm.run() == Gtk.ResponseType.ACCEPT:
			cm.hide()
			print(cm.get_response())
	cm.destroy()
	exit(0)
