#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# pushbullet_service.py
#
# This file is part of PushBullet-Indicator
#
# Copyright (C) 2014
# Lorenzo Carbonell Cerezo <lorenzo.carbonell.cerezo@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from gi.repository import Gtk
import dbus
import dbus.service
import json
from dbus.mainloop.glib import DBusGMainLoop
import os
from pushbulletapi import PushBullet

print(dbus.__version__)

class PushBulletDBUSService(dbus.service.Object):
	def __init__(self):
		bus_name = dbus.service.BusName('es.atareao.pushbullet', bus=dbus.SessionBus())
		dbus.service.Object.__init__(self, bus_name, '/es/atareao/pushbullet')
		self.pushBullet = PushBullet()

	@dbus.service.method('es.atareao.pushbullet')
	def restart(self):
		self.pushBullet = PushBullet()


	@dbus.service.method('es.atareao.pushbullet')
	def get_source_user_iden(self):
		return self.pushBullet.get_source_user_iden()

	@dbus.service.method('es.atareao.pushbullet')
	def get_source_device_iden(self):
		return self.pushBullet.get_source_device_iden()


	@dbus.service.method('es.atareao.pushbullet')
	def getPushHistory(self, modified_after=0, cursor=None):
		ans = self.pushBullet.getPushHistory(modified_after, cursor)
		return json.dumps(ans)

	@dbus.service.method('es.atareao.pushbullet')
	def getLastPush(self):
		ans = self.pushBullet.getLastPush()
		return json.dumps(ans)

	@dbus.service.method('es.atareao.pushbullet')
	def getDevices(self):
		return json.dumps(self.pushBullet.getDevices())

	@dbus.service.method('es.atareao.pushbullet')
	def getUser(self):
		return json.dumps(self.pushBullet.getUser())
	
	@dbus.service.method('es.atareao.pushbullet')
	def getContacts(self):
		return json.dumps(self.pushBullet.getContacts())
	
	@dbus.service.method('es.atareao.pushbullet')
	def updateDevices(self):
		self.pushBullet.updateDevices()
		return self.getDevices()

	@dbus.service.method('es.atareao.pushbullet')
	def updateContacts(self):
		self.pushBullet.updateContacts()
		return self.getContacts()
	
	@dbus.service.method('es.atareao.pushbullet')
	def is_pushing(self):
		return self.pushing
	
	@dbus.service.method('es.atareao.pushbullet')
	def send_file(self,identification,filename, body, iscontact):
		self.pushing(True,'file')
		self.pushBullet.pushFile(identification,filename, body, iscontact)
		self.pushing(False,'file')

	@dbus.service.method('es.atareao.pushbullet')
	def send_link(self,identification,title,body, link, iscontact):
		self.pushing(True,'link')
		self.pushBullet.pushLink(identification,title,body,link, iscontact)
		self.pushing(False,'link')

	@dbus.service.method('es.atareao.pushbullet')
	def send_note(self,identification,title,body, iscontact):
		self.pushing(True,'note')
		self.pushBullet.pushNote(identification,title,body, iscontact)
		self.pushing(False,'note')

	@dbus.service.method('es.atareao.pushbullet')
	def send_copy(self, body):
		self.pushing(True,'copy')
		self.pushBullet.pushCopy(body)
		self.pushing(False,'copy')

	@dbus.service.method('es.atareao.pushbullet')
	def send_reply(self, package_name, source_user_iden, target_device_iden, conversation_iden, message):
		self.pushing(True,'reply')
		self.pushBullet.sendReply(package_name, source_user_iden, target_device_iden,conversation_iden,message)
		self.pushing(False,'reply')

	@dbus.service.method('es.atareao.pushbullet')
	def send_sms(self, device_iden, number, message):
		self.pushing(True,'reply')
		self.pushBullet.pushSMS(device_iden, number, message)
		self.pushing(False,'reply')

		
	@dbus.service.method('es.atareao.pushbullet')
	def create_device(self, name, model):
		return json.dumps(self.pushBullet.createDevice(name, model))

	@dbus.service.method('es.atareao.pushbullet')
	def delete_device(self, device_iden):
		return json.dumps(self.pushBullet.deleteDevice(device_iden))

	@dbus.service.method('es.atareao.pushbullet')
	def set_pushing(self, is_pushing,kind,push=None):
		self.pushing(is_pushing,kind,push)

	@dbus.service.signal('es.atareao.pushbullet')
	def pushing(self, is_pushing,kind,push=None):
		pass
	@dbus.service.method('es.atareao.pushbullet')
	def is_login(self):
		return self.pushBullet.isLogin()

if __name__ == '__main__':
	DBusGMainLoop(set_as_default=True)
	mPushBulletDBUSService = PushBulletDBUSService()
	print(mPushBulletDBUSService.getDevices())
	#print(mPushBulletDBUSService.set_apikey('ddd'))
	Gtk.main() 
